Re-exports
pub use crate::codex_patch_plan::CodexPatchMode;pub use crate::codex_patch_plan::CodexSwitchOptions;
Structs
- Claude
Switch Status - Codex
Bridge Diagnostic Check - Codex
Bridge Diagnostics - Codex
Bridge Runtime Auth Snapshot - Codex
Remote Control Enablement - Codex
Remote Control Status - Codex
Startup Readiness - Codex
Startup Readiness Input - Codex
Startup Readiness Issue - Codex
Switch Status
Enums
Functions
- claude_
switch_ off - claude_
switch_ on - claude_
switch_ status - codex_
bridge_ diagnostics - codex_
bridge_ runtime_ auth_ snapshot - codex_
config_ text_ for_ import - codex_
remote_ control_ enable - codex_
remote_ control_ status - codex_
remote_ control_ successful_ enablement_ log_ seen - codex_
switch_ state_ exists - codex_
switch_ status - codex_
tui_ startup_ readiness - guard_
claude_ settings_ before_ switch_ on_ interactive - Warn before replacing an existing local Claude proxy patch.
- guard_
codex_ config_ before_ switch_ on_ interactive - Warn before replacing an existing local Codex proxy patch.
- patch_
codex_ auth_ for_ chatgpt_ bridge - switch_
off - Undo the local Codex proxy patch while preserving config edits made during the run.
- switch_
on - Switch Codex to use the local codex-helper model provider.
- switch_
on_ with_ configured_ preset - Switch Codex to use the local codex-helper model provider using the preset configured in
~/.codex-helper/config.toml. - switch_
on_ with_ mode - Switch Codex to use the local codex-helper model provider with an explicit client preset.
- switch_
on_ with_ options - Switch Codex to use the local codex-helper model provider with an explicit client preset and transport options.