Module bootstrap

Module bootstrap 

Functions

import_codex_config_from_codex_cli
显式从 Codex CLI 的配置文件(~/.codex/config.toml + auth.json)导入/刷新 codex 段配置。
load_or_bootstrap_for_service
Unified entry to load proxy config and, if necessary, bootstrap upstreams from the official Codex / Claude configuration files.
load_or_bootstrap_from_claude
load_or_bootstrap_from_codex
加载代理配置,如有必要从 ~/.codex 自动初始化 codex 配置。
overwrite_codex_config_from_codex_cli_in_place
Overwrite Codex configs from ~/.codex/config.toml + auth.json (in-place).
probe_codex_bootstrap_from_cli
Probe whether we can successfully bootstrap Codex upstreams from ~/.codex/config.toml and ~/.codex/auth.json without mutating any codex-helper configs. Intended for diagnostics (codex-helper doctor).