pub enum ReasoningGuardRetryExhaustedAction {
Pass,
Block,
}Variants
Pass
Forward the final matching upstream response after the guard retry budget is used.
Block
Convert the final matching upstream response to a local guard error.