pub struct ServiceControlProfile {
pub extends: Option<String>,
pub station: Option<String>,
pub model: Option<String>,
pub reasoning_effort: Option<String>,
pub service_tier: Option<String>,
}Fields
extends: Option<String>station: Option<String>Retained for legacy/v2 profiles. V4 route graph configs should express provider selection in the service routing block instead of profile-level station bindings.
model: Option<String>reasoning_effort: Option<String>service_tier: Option<String>Trait Implementations
Sourceimpl Clone for ServiceControlProfile
impl Clone for ServiceControlProfile
Sourcefn clone(&self) -> ServiceControlProfile
fn clone(&self) -> ServiceControlProfile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServiceControlProfile
impl Debug for ServiceControlProfile
Sourceimpl Default for ServiceControlProfile
impl Default for ServiceControlProfile
Sourcefn default() -> ServiceControlProfile
fn default() -> ServiceControlProfile
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ServiceControlProfile
impl<'de> Deserialize<'de> for ServiceControlProfile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ServiceControlProfile
impl PartialEq for ServiceControlProfile
Sourcefn eq(&self, other: &ServiceControlProfile) -> bool
fn eq(&self, other: &ServiceControlProfile) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ServiceControlProfile
impl Serialize for ServiceControlProfile
impl Eq for ServiceControlProfile
impl StructuralPartialEq for ServiceControlProfile