Module codex_integration

Module codex_integration 

Re-exports

pub use crate::codex_patch_plan::CodexPatchMode;
pub use crate::codex_patch_plan::CodexSwitchOptions;

Structs

ClaudeSwitchStatus
CodexBridgeDiagnosticCheck
CodexBridgeDiagnostics
CodexBridgeRuntimeAuthSnapshot
CodexRemoteControlEnablement
CodexRemoteControlStatus
CodexStartupReadiness
CodexStartupReadinessInput
CodexStartupReadinessIssue
CodexSwitchStatus

Enums

CodexBridgeDiagnosticStatus
CodexStartupReadinessIssueKind
CodexStartupReadinessSeverity

Functions

claude_switch_off
claude_switch_on
claude_switch_status
codex_bridge_diagnostics
codex_bridge_runtime_auth_snapshot
codex_config_text_for_import
codex_remote_control_enable
codex_remote_control_status
codex_remote_control_successful_enablement_log_seen
codex_switch_state_exists
codex_switch_status
codex_tui_startup_readiness
guard_claude_settings_before_switch_on_interactive
Warn before replacing an existing local Claude proxy patch.
guard_codex_config_before_switch_on_interactive
Warn before replacing an existing local Codex proxy patch.
patch_codex_auth_for_chatgpt_bridge
switch_off
Undo the local Codex proxy patch while preserving config edits made during the run.
switch_on
Switch Codex to use the local codex-helper model provider.
switch_on_with_mode
Switch Codex to use the local codex-helper model provider with an explicit client preset.
switch_on_with_options
Switch Codex to use the local codex-helper model provider with an explicit client preset and transport options.