Module codex_integration

Module codex_integration 

Structs

ClaudeSwitchStatus
CodexSwitchStatus

Functions

claude_switch_off
claude_switch_on
claude_switch_status
codex_config_text_for_import
codex_switch_state_exists
codex_switch_status
guard_claude_settings_before_switch_on_interactive
Warn before replacing an existing local Claude proxy patch.
guard_codex_config_before_switch_on_interactive
Warn before replacing an existing local Codex proxy patch.
switch_off
Undo the local Codex proxy patch while preserving config edits made during the run.
switch_on
Switch Codex to use the local codex-helper model provider.