CodexPatchMode

Enum CodexPatchMode 

pub enum CodexPatchMode {
    Default,
    ChatGptBridge,
    ImagegenBridge,
    OfficialRelayBridge,
    OfficialImagegenBridge,
}

Variants



Default

Keep the historical codex-helper patch behavior.



ChatGptBridge

Keep Codex/ChatGPT account auth for app/mobile features while model traffic goes through codex-helper.



ImagegenBridge

Use a minimal ChatGPT-looking auth facade to expose Codex hosted image generation while request credentials still come from codex-helper routing/upstream configuration.



OfficialRelayBridge

Advertise the local relay as the official OpenAI Responses provider so Codex can use first-party HTTP features that helper can safely forward, starting with remote compaction v1. Request credentials still come from codex-helper routing/upstream configuration.



OfficialImagegenBridge

Combine official relay provider identity for remote compaction with the image generation ChatGPT auth facade. Request credentials still come from codex-helper routing/upstream configuration.

Implementations

Source

impl CodexPatchMode

pub fn as_str(self) -> &'static str

pub fn as_preset_str(self) -> &'static str

pub fn is_default(self) -> bool

pub fn strips_codex_client_auth(self) -> bool

pub fn enables_official_relay_features(self) -> bool

pub fn enables_imagegen_facade(self) -> bool