Functions
- import_
codex_ config_ from_ codex_ cli - 显式从 Codex CLI 的配置文件(~/.codex/config.toml + auth.json)导入/刷新 codex 段配置。
- load_
or_ bootstrap_ for_ service - Unified entry to load proxy config and, if necessary, bootstrap upstreams from the official Codex / Claude configuration files.
- load_
or_ bootstrap_ from_ claude - load_
or_ bootstrap_ from_ codex - 加载代理配置,如有必要从 ~/.codex 自动初始化 codex 配置。
- overwrite_
codex_ config_ from_ codex_ cli_ in_ place - Overwrite Codex configs from ~/.codex/config.toml + auth.json (in-place).
- probe_
codex_ bootstrap_ from_ cli - Probe whether we can successfully bootstrap Codex upstreams from
~/.codex/config.toml and ~/.codex/auth.json without mutating any
codex-helper configs. Intended for diagnostics (
codex-helper doctor).